about summary refs log tree commit diff
diff options
context:
space:
mode:
author王宇逸 <Strawberry_Str@hotmail.com>2025-03-21 12:50:27 +0800
committer王宇逸 <Strawberry_Str@hotmail.com>2025-03-21 12:50:27 +0800
commite5fc7d6a55fd3318f7e457bb27df0de3089dcc0a (patch)
tree14d8f11508b9317a1d2e8c7a99877334a86284ee
parenteda7820be557755217e04242f195d1530524f399 (diff)
downloadrust-e5fc7d6a55fd3318f7e457bb27df0de3089dcc0a.tar.gz
rust-e5fc7d6a55fd3318f7e457bb27df0de3089dcc0a.zip
Fix Thread::set_name on cygwin
-rw-r--r--library/std/src/sys/pal/unix/thread.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/library/std/src/sys/pal/unix/thread.rs b/library/std/src/sys/pal/unix/thread.rs
index bffe2536299..bb34c2fabe5 100644
--- a/library/std/src/sys/pal/unix/thread.rs
+++ b/library/std/src/sys/pal/unix/thread.rs
@@ -143,8 +143,8 @@ impl Thread {
     pub fn set_name(name: &CStr) {
         unsafe {
             cfg_if::cfg_if! {
-                if #[cfg(target_os = "linux")] {
-                    // Linux limits the allowed length of the name.
+                if #[cfg(any(target_os = "linux", target_os = "cygwin"))] {
+                    // Linux and Cygwin limits the allowed length of the name.
                     const TASK_COMM_LEN: usize = 16;
                     let name = truncate_cstr::<{ TASK_COMM_LEN }>(name);
                 } else {
@@ -346,6 +346,7 @@ impl Drop for Thread {
     target_os = "solaris",
     target_os = "illumos",
     target_os = "vxworks",
+    target_os = "cygwin",
     target_vendor = "apple",
 ))]
 fn truncate_cstr<const MAX_WITH_NUL: usize>(cstr: &CStr) -> [libc::c_char; MAX_WITH_NUL] {